@@ -26,7 +26,7 @@ from .api.lookup import (
     SecurityCategoriesLookUpAPI,
     TimeSeriesLookUpAPI,
 )
-from .api.migration import InstanceSourceAPI, MigrationAPI
+from .api.migration import InstanceSourceAPI, MigrationAPI, ViewSourceAPI
 from .api.robotics import RoboticsAPI
 from .api.robotics.capabilities import CapabilitiesAPI
 from .api.robotics.data_postprocessing import DataPostProcessingAPI
@@ -71,6 +71,7 @@ class ToolkitClientMock(CogniteClientMock):
         self.lookup.extraction_pipelines = MagicMock(spec_set=ExtractionPipelineLookUpAPI)
         self.migration = MagicMock(spec=MigrationAPI)
         self.migration.instance_source = MagicMock(spec_set=InstanceSourceAPI)
+        self.migration.view_source = MagicMock(spec_set=ViewSourceAPI)
         self.raw = MagicMock(spec=ExtendedRawAPI)
         self.raw.databases = MagicMock(spec_set=RawDatabasesAPI)
         self.raw.rows = MagicMock(spec_set=RawRowsAPI)
